## $Id: pdf.py 15425 2019-05-24 16:22:09Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Reusable components for pdf generation.
"""

import os
import grok
from waeup.kofa.browser.pdf import PDFCreator, LandscapePDFCreator

class CustomPDFCreator(PDFCreator):
    """A utility to help with generating PDF docs.
    """

    header_logo_path = os.path.join(
        os.path.dirname(__file__), 'static', 'pdf_logo.jpg')
    watermark_path = os.path.join(
        os.path.dirname(__file__), 'static', 'pdf_watermark.jpg')

    watermark_pos = [-25, 100]
    logo_pos = [507, 720, 40]


class CustomLandscapePDFCreator(LandscapePDFCreator):
    """A utility to help with generating PDF docs in
    landscape format. No watermark is shown.
    """

    header_logo_path = os.path.join(
        os.path.dirname(__file__), 'static', 'pdf_logo.jpg')
    #watermark_path = os.path.join(
    #    os.path.dirname(__file__), 'static', 'pdf_watermark.jpg')

    #watermark_pos = [200, 55]
    logo_pos = [750, 480, 45]


class AkokaPDFCreator(PDFCreator):

    grok.name('akoka_pdfcreator')

    watermark_path = os.path.join(
        os.path.dirname(__file__), 'static', 'pdf_watermark.jpg')

    watermark_pos = [-25, 100]

    # right (default) logo
    header_logo_path = os.path.join(
        os.path.dirname(__file__), 'static', 'pdf_logo.jpg')

    logo_pos = [507, 720, 40]

    # left logo
    header_logo_left_path = os.path.join(
        os.path.dirname(__file__), 'static', 'pdf_logo_akoka.jpg')

    # logo_left_pos = [50, 680, 30]   # bottom aligned

    logo_left_pos = [50, 675, 30] # top aligned